@@ -2,11 +2,11 @@ use std::str::from_utf8;
 
 use pktparse::tcp::{self, TcpHeader};
 
-use centrifuge::http;
-use centrifuge::tls;
+use crate::centrifuge::http;
+use crate::centrifuge::tls;
 
-use structs::CentrifugeError;
-use structs::tcp::TCP;
+use crate::structs::CentrifugeError;
+use crate::structs::tcp::TCP;
 
 
 pub fn parse(remaining: &[u8]) -> Result<(tcp::TcpHeader, TCP), CentrifugeError> {
@@ -22,23 +22,14 @@ pub fn parse(remaining: &[u8]) -> Result<(tcp::TcpHeader, TCP), CentrifugeError>
 }
 
 #[inline]
-pub fn extract(tcp_hdr: &TcpHeader, remaining: &[u8]) -> Result<TCP, CentrifugeError> {
+pub fn extract(_tcp_hdr: &TcpHeader, remaining: &[u8]) -> Result<TCP, CentrifugeError> {
     if remaining.is_empty() {
-        Ok(TCP::Binary(Vec::new()))
-    } else if tcp_hdr.dest_port == 443 {
-        let client_hello = tls::extract(remaining)?;
+        Ok(TCP::Empty)
+    } else if let Ok(client_hello) = tls::extract(remaining) {
         Ok(TCP::TLS(client_hello))
-    } else if tcp_hdr.source_port == 443 {
-        // ignore
-        /*
-        if tcp_hdr.source_port == 443 {
-            let x = tls_parser::parse_tls_plaintext(remaining);
-            println!("tls(in): {:?}", &x);
-        }
-        */
-        Err(CentrifugeError::UnknownProtocol)
-    } else if tcp_hdr.dest_port == 80 {
-        let http = http::extract(remaining)?;
+    } else if let Ok(server_hello) = tls::extract(remaining) {
+        Ok(TCP::TLS(server_hello))
+    } else if let Ok(http) = http::extract(remaining) {
         Ok(TCP::HTTP(http))
     } else {
         Err(CentrifugeError::UnknownProtocol)
