@@ -1,5 +1,5 @@
 use structopt::StructOpt;
-use structopt::clap::AppSettings;
+use structopt::clap::{AppSettings, Shell};
 
 #[derive(Debug, StructOpt)]
 #[structopt(global_settings = &[AppSettings::ColoredHelp])]
@@ -25,6 +25,14 @@ The default only shows few packets, this flag can be specified multiple times. (
     /// Number of packet parsing threads (defaults to number of cpu cores)
     #[structopt(short="n", long="threads", alias="cpus")]
     pub threads: Option<usize>,
+    /// Disable syscall filter sandbox,
+    /// this flag disables security features in sniffglue,
+    /// please file a bug report if you need this option
+    #[structopt(long)]
+    pub insecure_disable_seccomp: bool,
+    /// Generate shell completions
+    #[structopt(long, hidden=true)]
+    pub gen_completions: Option<Shell>,
     /// The device or file to read packets from
     pub device: Option<String>,
 }
