@@ -1,9 +1,7 @@
 use std::sync::Arc;
 
-use pktparse;
 use reduce::Reduce;
 use ansi_term::Color::{self, Yellow, Blue, Green, Red, Purple, Fixed};
-use serde_json;
 use std::cmp;
 use std::fmt::Debug;
 
@@ -231,10 +229,8 @@ impl Format {
             TLS(tls::TLS::ClientHello(client_hello)) => {
                 let extra = display_kv_list(&[
                     ("version", client_hello.version),
-                    ("session", client_hello.session_id.as_ref()
-                        .map(|s| s.as_str())),
-                    ("hostname", client_hello.hostname.as_ref()
-                        .map(|s| s.as_str())),
+                    ("session", client_hello.session_id.as_deref()),
+                    ("hostname", client_hello.hostname.as_deref()),
                 ]);
 
                 out.push_str("[tls] ClientHello");
@@ -244,8 +240,7 @@ impl Format {
             TLS(tls::TLS::ServerHello(server_hello)) => {
                 let extra = display_kv_list(&[
                     ("version", server_hello.version),
-                    ("session", server_hello.session_id.as_ref()
-                        .map(|s| s.as_str())),
+                    ("session", server_hello.session_id.as_deref()),
                     ("cipher", server_hello.cipher),
                 ]);
 
@@ -328,9 +323,8 @@ impl Format {
                     Request(req) => {
                         out.push_str("[dns] req, ");
 
-                        match req.questions.iter()
-                            .map(|x| format!("{:?}", x))
-                            .reduce(|a, b| a + &align(out.len(), &b))
+                        match Reduce::reduce(req.questions.iter()
+                            .map(|x| format!("{:?}", x)), |a, b| a + &align(out.len(), &b))
                         {
                             Some(dns) => out.push_str(&dns),
                             None => out.push_str("[]"),
@@ -339,9 +333,8 @@ impl Format {
                     Response(resp) => {
                         out.push_str("[dns] resp, ");
 
-                        match resp.answers.iter()
-                            .map(|x| format!("{:?}", x))
-                            .reduce(|a, b| a + &align(out.len(), &b))
+                        match Reduce::reduce(resp.answers.iter()
+                            .map(|x| format!("{:?}", x)), |a, b| a + &align(out.len(), &b))
                         {
                             Some(dns) => out.push_str(&dns),
                             None => out.push_str("[]"),
@@ -534,13 +527,12 @@ fn display_macadr_buf(mac: [u8; 6]) -> String {
 
 #[inline]
 fn display_kv_list(list: &[(&str, Option<&str>)]) -> String {
-    list.iter()
+    Reduce::reduce(list.iter()
         .filter_map(|&(key, ref value)| {
             value.as_ref().map(|value| {
                 format!("{}: {:?}", key, value)
             })
-        })
-        .reduce(|a, b| a + ", " + &b)
+        }), |a, b| a + ", " + &b)
         .map(|extra| format!(" ({})", extra))
         .unwrap_or_else(String::new)
 }
@@ -557,24 +549,20 @@ impl<'a> DhcpKvListWriter<'a> {
     }
 
     fn append<T: Debug>(mut self, key: &'a str, value: &Option<T>) -> Self {
-        match value {
-            Some(value) => {
-                self.elements.push((
-                    key,
-                    format!("{:?}", value),
-                ));
-            }
-            _ => {}
+        if let Some(value) = value {
+            self.elements.push((
+                key,
+                format!("{:?}", value),
+            ));
         }
         self
     }
 
     fn finalize(self) -> String {
-        self.elements.iter()
+        Reduce::reduce(self.elements.iter()
             .map(|&(key, ref value)| {
                 format!("{}: {}", key, value)
-            })
-            .reduce(|a, b| a + ", " + &b)
+            }), |a, b| a + ", " + &b)
             .map(|extra| format!(" ({})", extra))
             .unwrap_or_else(String::new)
     }
